(install)=

# Installation

## Dependencies

- Python
- [Xarray](https://xarray.dev/)
- [Pyproj](https://pyproj4.github.io/pyproj/stable/)

## Built distributions

XProj packages are available on [PyPI](https://pypi.org/project/spherely/) (soon
on [conda-forge](https://conda-forge.org/) as well).

Install ``xproj`` and its dependencies, e.g., using [pip](https://pip.pypa.io/):

``` sh
$ pip install xproj
```

## Installation from source

Installing XProj from source may be useful for development purpose.

Clone XProj's [source repository](https://github.com/benbovy/xproj) and then
install it from the source root directory:

```sh
$ git clone https://github.com/benbovy/xproj
$ cd xproj
$ python -m pip install -e .
```
